<?php

/**
 * This is the model class for table "bill".
 *
 * The followings are the available columns in table 'bill':
 * @property string $billno
 * @property string $bpid
 * @property string $billtype
 * @property string $rtbno
 * @property string $billdate
 * @property string $billto
 * @property string $shipto
 * @property integer $pax
 * @property string $arrivetime
 * @property string $leavetime
 * @property string $billnote
 * @property string $billtotal
 * @property string $paystatus
 * @property string $billstatus
 * @property string $srepid
 * @property string $hostid
 * @property string $bpname
 * @property string $bpphone
 * @property string $dpamt
 *
 * The followings are the available model relations:
 * @property Deli[] $delis
 * @property Sale[] $sales
 * @property So[] $sos
 * @property Host $host
 * @property Billtype $billtype0
 * @property Bp $bp
 * @property Srep $srep
 * @property Hostwo[] $hostwos
 */
class Bill extends CActiveRecord {

    public $billno = 'AUTO';

    /**
     * Returns the static model of the specified AR class.
     * @param string $className active record class name.
     * @return Bill the static model class
     */
    public static function model($className=__CLASS__) {
        return parent::model($className);
    }

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return 'bill';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('bpid, pax, hostid, billtype, arrivetime, srepid', 'required'),
            array('pax', 'numerical', 'integerOnly' => true),
            array('billno, bpid, billtype, rtbno', 'length', 'max' => 15),
            array('billto, shipto, billnote', 'length', 'max' => 255),
            array('billtotal, dpamt', 'length', 'max' => 19),
            array('paystatus', 'length', 'max' => 1),
            array('billstatus, srepid', 'length', 'max' => 10),
            array('bpname, bpphone', 'length', 'max' => 100),
            array('billdate, arrivetime, leavetime, hostid', 'safe'),
            array('bpid', 'cekPosses'),
            // The following rule is used by search().
            // Please remove those attributes that should not be searched.
            array('billno, bpid, billtype, rtbno, billdate, billto, shipto, pax, arrivetime, leavetime, billnote, billtotal, paystatus, billstatus, srepid, hostid, bpname, bpphone, dpamt', 'safe', 'on' => 'search'),
        );
    }
    
    public function cekPosses() {
        if(!$this->hasErrors()){
            $count = Posses::model()->count('endtime IS NULL');
            if($count == 0){
                $this->addError('bpid', 'Belum buka kasir! Silahkan buka kasir terlebih dahulu !');
            }
        }
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'delis' => array(self::MANY_MANY, 'Deli', 'billdeli(billno, delino)'),
            'sales' => array(self::MANY_MANY, 'Sale', 'billsale(billno, saleno)'),
            'sos' => array(self::MANY_MANY, 'So', 'billso(billno, sono)'),
            'host' => array(self::BELONGS_TO, 'Host', 'hostid'),
            'billtype0' => array(self::BELONGS_TO, 'Billtype', 'billtype'),
            'bp' => array(self::BELONGS_TO, 'Bp', 'bpid'),
            'srep' => array(self::BELONGS_TO, 'Srep', 'srepid'),
            'hostwos' => array(self::HAS_MANY, 'Hostwo', 'billno'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'billno' => Yii::t('bill', 'billno'),
            'bpid' => Yii::t('bill', 'bpid'),
            'billtype' => Yii::t('bill', 'billtype'),
            'rtbno' => Yii::t('bill', 'rtbno'),
            'billdate' => Yii::t('bill', 'billdate'),
            'billto' => Yii::t('bill', 'billto'),
            'shipto' => Yii::t('bill', 'shipto'),
            'pax' => Yii::t('bill', 'pax'),
            'arrivetime' => Yii::t('bill', 'arrivetime'),
            'leavetime' => Yii::t('bill', 'leavetime'),
            'billnote' => Yii::t('bill', 'billnote'),
            'billtotal' => Yii::t('bill', 'billtotal'),
            'paystatus' => Yii::t('bill', 'paystatus'),
            'billstatus' => Yii::t('bill', 'billstatus'),
            'srepid' => Yii::t('bill', 'srepid'),
            'hostid' => Yii::t('bill', 'hostid'),
            'bpname' => Yii::t('bill', 'bpname'),
            'bpphone' => Yii::t('bill', 'bpphone'),
            'dpamt' => Yii::t('bill', 'dpamt'),
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
     */
    public function search() {
        // Warning: Please modify the following code to remove attributes that
        // should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('billno', $this->billno, true);
        $criteria->compare('bpid', $this->bpid, true);
        $criteria->compare('billtype', $this->billtype, true);
        $criteria->compare('rtbno', $this->rtbno, true);
        $criteria->compare('billdate', $this->billdate, true);
        $criteria->compare('billto', $this->billto, true);
        $criteria->compare('shipto', $this->shipto, true);
        $criteria->compare('pax', $this->pax);
        $criteria->compare('arrivetime', $this->arrivetime, true);
        $criteria->compare('leavetime', $this->leavetime, true);
        $criteria->compare('billnote', $this->billnote, true);
        $criteria->compare('billtotal', $this->billtotal, true);
        $criteria->compare('paystatus', $this->paystatus, true);
        $criteria->compare('billstatus', $this->billstatus, true);
        $criteria->compare('srepid', $this->srepid, true);
        $criteria->compare('hostid', $this->hostid, true);
        $criteria->compare('bpname', $this->bpname, true);
        $criteria->compare('bpphone', $this->bpphone, true);
        $criteria->compare('dpamt', $this->dpamt, true);

        return new CActiveDataProvider($this, array(
                    'criteria' => $criteria,
                ));
    }

    public function beforeSave() {
        if ($this->isNewRecord) {
            $ncount = new Ncount("BILL");
            $this->billno = $ncount->exec();
			$this->billdate = date('Y-m-d');
        }

        return true;
    }

    public function afterSave() {
        if ($this->isNewRecord) {
            $this->spBill_New($this->billno);
        }
    }

    public function spBill_New($billno) {
        $sp = new SP('spBill_New', array($billno));
        $sp->exec();
    }

    public function spBill_Cancel($billno) {
        $sp = new SP('spBill_Cancel', array($billno));
        $sp->exec();
    }
    
    public function spBill_Close($billno) {
        $sp = new SP('spBill_Close', array($billno));
        $sp->exec();
    }

    public function getBillByHostID($hostid) {
        $model = self::model()->find('hostid=:hostid AND leavetime IS NULL AND billtype=:billtype', array(':hostid' => $hostid, ':billtype' => 'DI'));

        return $model;
    }
    
    public function spBillOrder_Cancel() {
        $sp = new SP('spBillOrder_Cancel', array($this->billno, true));
        $sp->exec();
    }
    
    public function spBill_Move($oldhostid, $newhostid) {
        $sp = new SP('spBill_Move', array($this->billno, $oldhostid, $newhostid));
        $sp->exec();
    }
    
    public function newBillMove($oldhostid, $newhostid, $crtby, $reason){
        $ncount = new Ncount("BILLMOVE");
        $billmove = new Billmove();
        $billmove->billmoveno = $ncount->exec();
        $billmove->hostidnew = $newhostid;
        $billmove->hostidold = $oldhostid;
        $billmove->crtby = $crtby;
        $billmove->reason = $reason;
        return $billmove->save();
    }

}