<?php

/**
 * This is the model class for table "billmove".
 *
 * The followings are the available columns in table 'billmove':
 * @property string $billmoveno
 * @property string $crttime
 * @property string $crtby
 * @property string $reason
 * @property string $hostidold
 * @property string $hostidnew
 * @property boolean $isprinted
 *
 * The followings are the available model relations:
 * @property Host $hostidnew0
 * @property Host $hostidold0
 */
class Billmove extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return Billmove the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'billmove';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('billmoveno', 'required'),
			array('billmoveno', 'length', 'max'=>15),
			array('crtby', 'length', 'max'=>10),
			array('reason', 'length', 'max'=>200),
			array('crttime, hostidold, hostidnew, isprinted', 'safe'),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('billmoveno, crttime, crtby, reason, hostidold, hostidnew, isprinted', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'hostidnew0' => array(self::BELONGS_TO, 'Host', 'hostidnew'),
			'hostidold0' => array(self::BELONGS_TO, 'Host', 'hostidold'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'billmoveno' => Yii::t('billmove', 'billmoveno'),
			'crttime' => Yii::t('billmove', 'crttime'),
			'crtby' => Yii::t('billmove', 'crtby'),
			'reason' => Yii::t('billmove', 'reason'),
			'hostidold' => Yii::t('billmove', 'hostidold'),
			'hostidnew' => Yii::t('billmove', 'hostidnew'),
			'isprinted' => Yii::t('billmove', 'isprinted'),
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('billmoveno',$this->billmoveno,true);
		$criteria->compare('crttime',$this->crttime,true);
		$criteria->compare('crtby',$this->crtby,true);
		$criteria->compare('reason',$this->reason,true);
		$criteria->compare('hostidold',$this->hostidold,true);
		$criteria->compare('hostidnew',$this->hostidnew,true);
		$criteria->compare('isprinted',$this->isprinted);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
	
	public function beforeSave() {
        if ($this->isNewRecord) {
            $ncount = new Ncount("BILLMOVE");
            $this->billmoveno = $ncount->exec();
            $this->crttime = date('Y-m-d H:i:s');
            
        }

        return true;
    }
}