<?php

/**
 * This is the model class for table "posses".
 *
 * The followings are the available columns in table 'posses':
 * @property string $possesno
 * @property string $posid
 * @property string $empid
 * @property string $usrid
 * @property string $possesdate
 * @property string $shift
 * @property string $starttime
 * @property string $startbal
 * @property string $totin
 * @property string $totout
 * @property string $endtime
 * @property string $endbal
 * @property boolean $iscollect
 * @property boolean $_xt
 * @property string $printdate
 *
 * The followings are the available model relations:
 * @property Bill[] $bills
 * @property Usr $usr
 * @property Pos $pos
 * @property Emp $emp
 * @property Sale[] $sales
 */
class Posses extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return Posses the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'posses';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('possesno', 'required'),
			array('possesno', 'length', 'max'=>8),
			array('posid', 'length', 'max'=>5),
			array('empid', 'length', 'max'=>15),
			array('usrid', 'length', 'max'=>10),
			array('shift', 'length', 'max'=>2),
			array('startbal, totin, totout, endbal', 'length', 'max'=>19),
			array('possesdate, starttime, endtime, iscollect, _xt, printdate', 'safe'),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('possesno, posid, empid, usrid, possesdate, shift, starttime, startbal, totin, totout, endtime, endbal, iscollect, _xt, printdate', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'bills' => array(self::HAS_MANY, 'Bill', 'possesno'),
			'usr' => array(self::BELONGS_TO, 'Usr', 'usrid'),
			'pos' => array(self::BELONGS_TO, 'Pos', 'posid'),
			'emp' => array(self::BELONGS_TO, 'Emp', 'empid'),
			'sales' => array(self::HAS_MANY, 'Sale', 'possesno'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'possesno' => Yii::t('posses', 'possesno'),
			'posid' => Yii::t('posses', 'posid'),
			'empid' => Yii::t('posses', 'empid'),
			'usrid' => Yii::t('posses', 'usrid'),
			'possesdate' => Yii::t('posses', 'possesdate'),
			'shift' => Yii::t('posses', 'shift'),
			'starttime' => Yii::t('posses', 'starttime'),
			'startbal' => Yii::t('posses', 'startbal'),
			'totin' => Yii::t('posses', 'totin'),
			'totout' => Yii::t('posses', 'totout'),
			'endtime' => Yii::t('posses', 'endtime'),
			'endbal' => Yii::t('posses', 'endbal'),
			'iscollect' => Yii::t('posses', 'iscollect'),
			'_xt' => Yii::t('posses', '_xt'),
			'printdate' => Yii::t('posses', 'printdate'),
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('possesno',$this->possesno,true);
		$criteria->compare('posid',$this->posid,true);
		$criteria->compare('empid',$this->empid,true);
		$criteria->compare('usrid',$this->usrid,true);
		$criteria->compare('possesdate',$this->possesdate,true);
		$criteria->compare('shift',$this->shift,true);
		$criteria->compare('starttime',$this->starttime,true);
		$criteria->compare('startbal',$this->startbal,true);
		$criteria->compare('totin',$this->totin,true);
		$criteria->compare('totout',$this->totout,true);
		$criteria->compare('endtime',$this->endtime,true);
		$criteria->compare('endbal',$this->endbal,true);
		$criteria->compare('iscollect',$this->iscollect);
		$criteria->compare('_xt',$this->_xt);
		$criteria->compare('printdate',$this->printdate,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
}